.. Slicer Package Manager documentation main file, created by
   sphinx-quickstart on Mon Feb 12 16:59:31 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Slicer Package Manager's documentation!
==================================================

The **Slicer Package Manager** includes a REST API service and CLI built on `Girder`_ for downloading, uploading
and organizing application and extension packages for both `3D Slicer`_ and `3D Slicer-based`_ applications.

.. _Girder: https://github.com/girder/girder
.. _3D Slicer: https://slicer.org
.. _3D Slicer-based: https://github.com/KitwareMedical/SlicerCustomAppTemplate

.. toctree::
   :maxdepth: 1

   overview
   concepts
   commands_shell
   faq
   installation
   developer_guide/index
   authors
   make_a_release
   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

